# Lda Over Time

[![PyPI - Version](https://img.shields.io/pypi/v/lda-over-time.svg)](https://pypi.org/project/lda-over-time)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/lda-over-time.svg)](https://pypi.org/project/lda-over-time)

-----

**Table of Contents**

- [About](#about)
- [Installation](#installation)
- [Tutorial](#tutorial)
- [License](#license)

## About

LdaOverTime is a framework that brings an easier way of doing Topic Modeling 
Analysis Over Time and get visualization of results.

In brief, Topic Modeling is a technique that finds topics that each document 
from a collection covers. And, by addind the time in this equation, we can 
study how much and why one certain topic is more or less discussed in a 
time slice.

## Installation

```console
pip install lda-over-time
```

## Tutorial
You can check out the library's tutorial and small example of usage at 
[notebooks/tutorial.ipynb](./notebooks/tutorial.ipynb).


## License

`lda-over-time` is distributed under the terms of the [LGPL3](./COPYING).

